# motorcalc - A package to calculate and plot DC - motors

Gerrit Kocherscheidt
KOCO MOTION / KOCO automotive, March 2023

## Basic usage
With this package a simple calculation of DC motor parameters based on the input voltage, no-load current, terminal resistance and torque constant is performed. 

## Installation

### Installation using `pip`
`pip install motorcalc`

### Installation of sources from Github
`git clone https://github.com/KOCOMOTION/motorcalc.git`
